pub enum Operation {
System(Box<SystemOperation>),
User {
application_id: ApplicationId,
bytes: Vec<u8>,
},
}Expand description
An operation to be executed in a block.
Variants
System(Box<SystemOperation>)
A system operation.
User
A user operation (in serialized form).
Fields
application_id: ApplicationIdThe ID of the application this operation targets.
Implementations
Sourceimpl Operation
impl Operation
Sourcepub fn system(operation: SystemOperation) -> Self
pub fn system(operation: SystemOperation) -> Self
Creates a new system operation.
Sourcepub fn user<A: Abi>(
application_id: ApplicationId<A>,
operation: &A::Operation,
) -> Result<Self, Error>
pub fn user<A: Abi>( application_id: ApplicationId<A>, operation: &A::Operation, ) -> Result<Self, Error>
Creates a new user application operation following the application_id’s Abi.
Sourcepub fn user_without_abi(
application_id: ApplicationId,
operation: &impl Serialize,
) -> Result<Self, Error>
pub fn user_without_abi( application_id: ApplicationId, operation: &impl Serialize, ) -> Result<Self, Error>
Creates a new user application operation assuming that the operation is valid for the
application_id.
Sourcepub fn as_system_operation(&self) -> Option<&SystemOperation>
pub fn as_system_operation(&self) -> Option<&SystemOperation>
Returns a reference to the SystemOperation in this Operation, if this Operation
is for the system application.
Sourcepub fn application_id(&self) -> GenericApplicationId
pub fn application_id(&self) -> GenericApplicationId
Returns the ID of the application this operation targets.
Sourcepub fn published_blob_ids(&self) -> Vec<BlobId>
pub fn published_blob_ids(&self) -> Vec<BlobId>
Returns the IDs of all blobs published in this operation.
Sourcepub fn is_exempt_from_permissions(&self) -> bool
pub fn is_exempt_from_permissions(&self) -> bool
Returns whether this operation is allowed regardless of application permissions.
Sourcepub fn is_update_stream(&self) -> bool
pub fn is_update_stream(&self) -> bool
Returns whether this operation is an UpdateStream operation.
Sourcepub fn is_checkpoint(&self) -> bool
pub fn is_checkpoint(&self) -> bool
Returns whether this operation is a Checkpoint operation.